/* Macro defintions of the get and set functions. */

#define ca_get_bindport	ca_get_int(CA_BINDPORT)
#define ca_set_bindport	ca_set_int(CA_BINDPORT)

#define ca_get_help	ca_get_dirlist(CA_HELP)
#define ca_set_help	ca_set_dirlist(CA_HELP)

#define ca_get_replybanner	ca_get_string(CA_REPLYBANNER)
#define ca_set_replybanner	ca_set_string(CA_REPLYBANNER)

#define ca_get_source	ca_get_source(CA_SOURCE)
#define ca_set_source	ca_set_source(CA_SOURCE)

#define ca_get_testmode	ca_get_boolean(CA_TESTMODE)
#define ca_set_testmode	ca_set_boolean(CA_TESTMODE)

#define ca_get_overridecryptedpw	ca_get_string(CA_OVERRIDECRYPTEDPW)
#define ca_set_overridecryptedpw	ca_set_string(CA_OVERRIDECRYPTEDPW)

#define ca_get_whoishelp	ca_get_dirlist(CA_WHOISHELP)
#define ca_set_whoishelp	ca_set_dirlist(CA_WHOISHELP)

#define ca_get_autodbmhelp	ca_get_dirlist(CA_AUTODBMHELP)
#define ca_set_autodbmhelp	ca_set_dirlist(CA_AUTODBMHELP)

#define ca_get_attdesc	ca_get_dirlist(CA_ATTDESC)
#define ca_set_attdesc	ca_set_dirlist(CA_ATTDESC)

#define ca_get_deflook	ca_get_source(CA_DEFLOOK)
#define ca_set_deflook	ca_set_source(CA_DEFLOOK)

#define ca_get_dbfile	ca_get_dirlist(CA_DBFILE)
#define ca_set_dbfile	ca_set_dirlist(CA_DBFILE)

#define ca_get_canupd	ca_get_source(CA_CANUPD)
#define ca_set_canupd	ca_set_source(CA_CANUPD)

#define ca_get_crossnotifysources	ca_get_source(CA_CROSSNOTIFYSOURCES)
#define ca_set_crossnotifysources	ca_set_source(CA_CROSSNOTIFYSOURCES)

#define ca_get_uid	ca_get_int(CA_UID)
#define ca_set_uid	ca_set_int(CA_UID)

#define ca_get_qrylog	ca_get_dirlist(CA_QRYLOG)
#define ca_set_qrylog	ca_set_dirlist(CA_QRYLOG)

#define ca_get_qry2log	ca_get_dirlist(CA_QRY2LOG)
#define ca_set_qry2log	ca_set_dirlist(CA_QRY2LOG)

#define ca_get_errlog	ca_get_dirlist(CA_ERRLOG)
#define ca_set_errlog	ca_set_dirlist(CA_ERRLOG)

#define ca_get_auditlog	ca_get_dirlist(CA_AUDITLOG)
#define ca_set_auditlog	ca_set_dirlist(CA_AUDITLOG)

#define ca_get_updlog	ca_get_dirlist(CA_UPDLOG)
#define ca_set_updlog	ca_set_dirlist(CA_UPDLOG)

#define ca_get_acklog	ca_get_dirlist(CA_ACKLOG)
#define ca_set_acklog	ca_set_dirlist(CA_ACKLOG)

#define ca_get_lockdir	ca_get_dirlist(CA_LOCKDIR)
#define ca_set_lockdir	ca_set_dirlist(CA_LOCKDIR)

#define ca_get_pidfile	ca_get_string(CA_PIDFILE)
#define ca_set_pidfile	ca_set_string(CA_PIDFILE)

#define ca_get_updatelock	ca_get_string(CA_UPDATELOCK)
#define ca_set_updatelock	ca_set_string(CA_UPDATELOCK)

#define ca_get_cleanlock	ca_get_string(CA_CLEANLOCK)
#define ca_set_cleanlock	ca_set_string(CA_CLEANLOCK)

#define ca_get_serialdir	ca_get_dirlist(CA_SERIALDIR)
#define ca_set_serialdir	ca_set_dirlist(CA_SERIALDIR)

#define ca_get_oldserialdir	ca_get_dirlist(CA_OLDSERIALDIR)
#define ca_set_oldserialdir	ca_set_dirlist(CA_OLDSERIALDIR)

#define ca_get_serialincomingdir	ca_get_dirlist(CA_SERIALINCOMINGDIR)
#define ca_set_serialincomingdir	ca_set_dirlist(CA_SERIALINCOMINGDIR)

#define ca_get_keepopen	ca_get_int(CA_KEEPOPEN)
#define ca_set_keepopen	ca_set_int(CA_KEEPOPEN)

#define ca_get_allocmnt	ca_get_string(CA_ALLOCMNT)
#define ca_set_allocmnt	ca_set_string(CA_ALLOCMNT)

#define ca_get_getupdatesfrom	ca_get_string(CA_GETUPDATESFROM)
#define ca_set_getupdatesfrom	ca_set_string(CA_GETUPDATESFROM)

#define ca_get_whoisupdfrom	ca_get_string(CA_WHOISUPDFROM)
#define ca_set_whoisupdfrom	ca_set_string(CA_WHOISUPDFROM)

#define ca_get_denywhoisaccess	ca_get_string(CA_DENYWHOISACCESS)
#define ca_set_denywhoisaccess	ca_set_string(CA_DENYWHOISACCESS)

#define ca_get_tmpdir	ca_get_dirlist(CA_TMPDIR)
#define ca_set_tmpdir	ca_set_dirlist(CA_TMPDIR)

#define ca_get_pgpv	ca_get_dirlist(CA_PGPV)
#define ca_set_pgpv	ca_set_dirlist(CA_PGPV)

#define ca_get_pgpk	ca_get_dirlist(CA_PGPK)
#define ca_set_pgpk	ca_set_dirlist(CA_PGPK)

#define ca_get_pgppath	ca_get_dirlist(CA_PGPPATH)
#define ca_set_pgppath	ca_set_dirlist(CA_PGPPATH)

#define ca_get_mailcmd	ca_get_dirlist(CA_MAILCMD)
#define ca_set_mailcmd	ca_set_dirlist(CA_MAILCMD)

#define ca_get_overflowsize	ca_get_int(CA_OVERFLOWSIZE)
#define ca_set_overflowsize	ca_set_int(CA_OVERFLOWSIZE)

#define ca_get_dbcachesize	ca_get_int(CA_DBCACHESIZE)
#define ca_set_dbcachesize	ca_set_int(CA_DBCACHESIZE)

#define ca_get_nrofnames	ca_get_int(CA_NROFNAMES)
#define ca_set_nrofnames	ca_set_int(CA_NROFNAMES)

#define ca_get_defmail	ca_get_string(CA_DEFMAIL)
#define ca_set_defmail	ca_set_string(CA_DEFMAIL)

#define ca_get_humailbox	ca_get_string(CA_HUMAILBOX)
#define ca_set_humailbox	ca_set_string(CA_HUMAILBOX)

#define ca_get_autobox	ca_get_string(CA_AUTOBOX)
#define ca_set_autobox	ca_set_string(CA_AUTOBOX)

#define ca_get_duplicatepersoncheck	ca_get_string(CA_DUPLICATEPERSONCHECK)
#define ca_set_duplicatepersoncheck	ca_set_string(CA_DUPLICATEPERSONCHECK)

#define ca_get_replybanner	ca_get_string(CA_REPLYBANNER)
#define ca_set_replybanner	ca_set_string(CA_REPLYBANNER)

#define ca_get_nomatch	ca_get_string(CA_NOMATCH)
#define ca_set_nomatch	ca_set_string(CA_NOMATCH)

#define ca_get_cn_subject_add	ca_get_string(CA_CN_SUBJECT_ADD)
#define ca_set_cn_subject_add	ca_set_string(CA_CN_SUBJECT_ADD)

#define ca_get_cn_subject_del	ca_get_string(CA_CN_SUBJECT_DEL)
#define ca_set_cn_subject_del	ca_set_string(CA_CN_SUBJECT_DEL)

#define ca_get_cn_explain_add	ca_get_string(CA_CN_EXPLAIN_ADD)
#define ca_set_cn_explain_add	ca_set_string(CA_CN_EXPLAIN_ADD)

#define ca_get_cn_explain_del	ca_get_string(CA_CN_EXPLAIN_DEL)
#define ca_set_cn_explain_del	ca_set_string(CA_CN_EXPLAIN_DEL)

#define ca_get_cn_overlap_add	ca_get_string(CA_CN_OVERLAP_ADD)
#define ca_set_cn_overlap_add	ca_set_string(CA_CN_OVERLAP_ADD)

#define ca_get_cn_overlap_del	ca_get_string(CA_CN_OVERLAP_DEL)
#define ca_set_cn_overlap_del	ca_set_string(CA_CN_OVERLAP_DEL)

#define ca_get_cno_subject_add	ca_get_string(CA_CNO_SUBJECT_ADD)
#define ca_set_cno_subject_add	ca_set_string(CA_CNO_SUBJECT_ADD)

#define ca_get_cno_subject_del	ca_get_string(CA_CNO_SUBJECT_DEL)
#define ca_set_cno_subject_del	ca_set_string(CA_CNO_SUBJECT_DEL)

#define ca_get_cno_explain_add	ca_get_string(CA_CNO_EXPLAIN_ADD)
#define ca_set_cno_explain_add	ca_set_string(CA_CNO_EXPLAIN_ADD)

#define ca_get_cno_explain_del	ca_get_string(CA_CNO_EXPLAIN_DEL)
#define ca_set_cno_explain_del	ca_set_string(CA_CNO_EXPLAIN_DEL)

#define ca_get_cno_overlap_add	ca_get_string(CA_CNO_OVERLAP_ADD)
#define ca_set_cno_overlap_add	ca_set_string(CA_CNO_OVERLAP_ADD)

#define ca_get_cno_overlap_del	ca_get_string(CA_CNO_OVERLAP_DEL)
#define ca_set_cno_overlap_del	ca_set_string(CA_CNO_OVERLAP_DEL)

#define ca_get_mailtxt	ca_get_string(CA_MAILTXT)
#define ca_set_mailtxt	ca_set_string(CA_MAILTXT)

#define ca_get_mheader	ca_get_string(CA_MHEADER)
#define ca_set_mheader	ca_set_string(CA_MHEADER)

#define ca_get_failuretxt	ca_get_string(CA_FAILURETXT)
#define ca_set_failuretxt	ca_set_string(CA_FAILURETXT)

#define ca_get_successtxt	ca_get_string(CA_SUCCESSTXT)
#define ca_set_successtxt	ca_set_string(CA_SUCCESSTXT)

#define ca_get_helpheader	ca_get_string(CA_HELPHEADER)
#define ca_set_helpheader	ca_set_string(CA_HELPHEADER)

#define ca_get_ackerr	ca_get_string(CA_ACKERR)
#define ca_set_ackerr	ca_set_string(CA_ACKERR)

#define ca_get_ackok	ca_get_string(CA_ACKOK)
#define ca_set_ackok	ca_set_string(CA_ACKOK)

#define ca_get_acksig	ca_get_string(CA_ACKSIG)
#define ca_set_acksig	ca_set_string(CA_ACKSIG)

#define ca_get_notitxt	ca_get_string(CA_NOTITXT)
#define ca_set_notitxt	ca_set_string(CA_NOTITXT)

#define ca_get_notimailtxt	ca_get_string(CA_NOTIMAILTXT)
#define ca_set_notimailtxt	ca_set_string(CA_NOTIMAILTXT)

#define ca_get_notinetworktxt	ca_get_string(CA_NOTINETWORKTXT)
#define ca_set_notinetworktxt	ca_set_string(CA_NOTINETWORKTXT)

#define ca_get_nheader	ca_get_string(CA_NHEADER)
#define ca_set_nheader	ca_set_string(CA_NHEADER)

#define ca_get_fwheader	ca_get_string(CA_FWHEADER)
#define ca_set_fwheader	ca_set_string(CA_FWHEADER)

#define ca_get_fwtxt	ca_get_string(CA_FWTXT)
#define ca_set_fwtxt	ca_set_string(CA_FWTXT)

#define ca_get_fwmailtxt	ca_get_string(CA_FWMAILTXT)
#define ca_set_fwmailtxt	ca_set_string(CA_FWMAILTXT)

#define ca_get_fwnetworktxt	ca_get_string(CA_FWNETWORKTXT)
#define ca_set_fwnetworktxt	ca_set_string(CA_FWNETWORKTXT)

#define ca_get_mtfwheader	ca_get_string(CA_MTFWHEADER)
#define ca_set_mtfwheader	ca_set_string(CA_MTFWHEADER)

#define ca_get_mtfwtxt	ca_get_string(CA_MTFWTXT)
#define ca_set_mtfwtxt	ca_set_string(CA_MTFWTXT)

#define ca_get_denyaccesstxt	ca_get_string(CA_DENYACCESSTXT)
#define ca_set_denyaccesstxt	ca_set_string(CA_DENYACCESSTXT)

#define ca_get_referraltxt	ca_get_string(CA_REFERRALTXT)
#define ca_set_referraltxt	ca_set_string(CA_REFERRALTXT)

#define ca_get_referralerrortxt	ca_get_string(CA_REFERRALERRORTXT)
#define ca_set_referralerrortxt	ca_set_string(CA_REFERRALERRORTXT)

#define ca_get_referrallooperrortxt	ca_get_string(REFERRALLOOPERRORTXT)
#define ca_set_referrallooperrortxt	ca_set_string(REFERRALLOOPERRORTXT)

#define ca_get_referraltimeouttxt	ca_get_string(REFERRALTIMEOUTTXT)
#define ca_set_referraltimeouttxt	ca_set_string(REFERRALTIMEOUTTXT)

#define ca_get_referraltrunctxt	ca_get_string(REFERRALTRUNCTXT)
#define ca_set_referraltrunctxt	ca_set_string(REFERRALTRUNCTXT)

#define ca_get_referralendtxt	ca_get_string(REFERRALENDTXT)
#define ca_set_referralendtxt	ca_set_string(REFERRALENDTXT)

#define ca_get_referraltimeout	ca_get_string(REFERRALTIMEOUT)
#define ca_set_referraltimeout	ca_set_string(REFERRALTIMEOUT)

#define ca_get_referralmaxlines	ca_get_string(REFERRALMAXLINES)
#define ca_set_referralmaxlines	ca_set_string(REFERRALMAXLINES)

#define ca_get_rights	ca_get_string(RIGHTS)
#define ca_set_rights	ca_set_string(RIGHTS)

#define ca_get_country	ca_get_string(COUNTRY)
#define ca_set_country	ca_set_string(COUNTRY)

#define ca_get_dictionary ca_getDictionary(dictionary, VARS)

#define ca_get_srcname(X)	ca_srchandle2Strelement((X), CA_SRCNAME)

#define ca_get_srccanupd(X)	ca_srchandle2Strelement((X), CA_DBCANUPD)

#define ca_get_srcdeflook(X) ca_srchandle2Strelement((X), CA_DBDEFLOOK)

#define ca_get_srcdbmachine(X) ca_srchandle2Strelement((X), CA_DBMACHINE)

#define ca_get_srcdbuser(X) ca_srchandle2Strelement((X), CA_DBUSER)

#define ca_get_srcdbpassword(X) ca_srchandle2Strelement((X), CA_DBPASSWORD)

#define ca_get_srcdbname(X) ca_srchandle2Strelement((X), CA_DBNAME)

#define ca_get_srcdbport(X) ca_srchandle2Intelement((X), CA_DBPORT)

#define ca_get_srcnrtmhost(X) ca_srchandle2Strelement((X), CA_NRTMHOST)

#define ca_get_srcnrtmlog(X) ca_srchandle2Strelement((X), CA_NRTMLOG)

#define ca_get_srcmode(X) ca_srchandle2Intelement((X), CA_SRCMODE)

#define ca_get_srcnrtmport(X) ca_srchandle2Intelement((X), CA_NRTMPORT)

#define ca_get_srcnrtmdelay(X) ca_srchandle2Intelement((X), CA_NRTMDELAY)

#define ca_get_srcnrtmprotocolvers(X) ca_srchandle2Intelement((X), CA_NRTMPROTOCOLVERS)

#define ca_get_srcupdateport(X) ca_srchandle2Intelement((X), CA_SRCUPDPORT)

#define ca_get_notiflog ca_get_dirlist(CA_NOTIFLOG)
#define ca_set_notiflog ca_set_dirlist(CA_NOTIFLOG)

#define ca_get_forwlog  ca_get_dirlist(CA_FORWLOG)
#define ca_set_forwlog  ca_set_dirlist(CA_FORWLOG)

#define ca_get_crosslog ca_get_dirlist(CA_CROSSLOG)
#define ca_set_crosslog ca_set_dirlist(CA_CROSSLOG)

#define ca_get_ripadminport ca_get_adminIntElement(CA_RIPADMIN, CA_ADMINPORT)
#define ca_get_ripadminuser ca_get_adminStrElement(CA_RIPADMIN, CA_ADMINUSER)

#define ca_get_ripadmintable ca_get_adminStrElement(CA_RIPADMIN, CA_ADMINTABLE)

#define ca_get_ripadminhost ca_get_adminStrElement(CA_RIPADMIN, CA_ADMINHOST)

#define ca_get_ripadminpassword ca_get_adminStrElement(CA_RIPADMIN, CA_ADMINPASSWORD)


